@@ -207,6 +207,9 @@ class AppstreamComponent:
         self.id: str = ""
         "The component ID"
 
+        self.type: str = "desktop"
+        "The type"
+
         self.name: TranslateableTag = TranslateableTag()
         "The component name"
 
@@ -261,9 +264,13 @@ class AppstreamComponent:
         self.update_contact: Optional[str] = None
         "The update contact"
 
+        self.extends: list[str] = []
+        "The extends tag for addons"
+
     def clear(self) -> None:
         """Resets the Component"""
         self.id = ""
+        self.type = "desktop"
         self.name.clear()
         self.developer_name.clear()
         self.summary.clear()
@@ -281,6 +288,7 @@ class AppstreamComponent:
         self.keywords.clear()
         self.kudos.clear()
         self.update_contact = None
+        self.extends.clear()
 
         for i in PROVIDES_TYPES:
             self.provides[i] = []
@@ -293,6 +301,11 @@ class AppstreamComponent:
     def parse_component_tag(self, tag: etree._ElementTree) -> None:
         self.id = tag.find("id").text
 
+        try:
+            self.type = tag.xpath("/component")[0].get("type")
+        except IndexError:
+            self.type = tag.get("type")
+
         self.name.load_tags(tag.findall("name"))
 
         self.developer_name.load_tags(tag.findall("developer_name"))
@@ -380,6 +393,9 @@ class AppstreamComponent:
         if update_contact_tag is not None:
             self.update_contact = update_contact_tag.text
 
+        for i in tag.findall("extends"):
+            self.extends.append(i.text)
+
     def load_file(self, path: str) -> None:
         """Load a appdata.xml or metainfo.xml file"""
         root = etree.parse(path)
@@ -387,6 +403,7 @@ class AppstreamComponent:
 
     def get_component_tag(self) -> etree.Element:
         tag = etree.Element("component")
+        tag.set("type", self.type)
 
         id_tag = etree.SubElement(tag, "id")
         id_tag.text = self.id
@@ -462,6 +479,10 @@ class AppstreamComponent:
             update_contact_tag = etree.SubElement(tag, "update_contact")
             update_contact_tag.text = self.update_contact
 
+        for i in self.extends:
+            extends_tag = etree.SubElement(tag, "extends")
+            extends_tag.text = i
+
         return tag
 
     def get_xml_string(self) -> str:
@@ -474,4 +495,4 @@ class AppstreamComponent:
             f.write(etree.tostring(self.get_component_tag(), pretty_print=True, xml_declaration=True, encoding="utf-8").decode("utf-8"))
 
     def __repr__(self) -> str:
-        return f"<AppstreamComponent id='{self.id}'>"
\ No newline at end of file
+        return f"<AppstreamComponent id='{self.id}'>"
